@@ -1,25 +1,35 @@
 /* Eliot                                                                     */
-/* Copyright (C) 1999  antoine.fraboulet                                     */
-/* antoine.fraboulet@free.fr                                                 */
+/* Copyright (C) 1999  Antoine Fraboulet                                     */
 /*                                                                           */
-/* This program is free software; you can redistribute it and/or modify      */
+/* This file is part of Eliot.                                               */
+/*                                                                           */
+/* Eliot is free software; you can redistribute it and/or modify             */
 /* it under the terms of the GNU General Public License as published by      */
 /* the Free Software Foundation; either version 2 of the License, or         */
 /* (at your option) any later version.                                       */
 /*                                                                           */
-/* This program is distributed in the hope that it will be useful,           */
+/* Eliot is distributed in the hope that it will be useful,                  */
 /* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
 /* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
 /* GNU General Public License for more details.                              */
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-/*	$Id: hashtable.h,v 1.1 2004/04/08 09:43:06 afrab Exp $	 */
+/**
+ *  \file   hashtable.h
+ *  \brief  Simple hashtable type
+ *  \author Antoine Fraboulet
+ *  \date   1999
+ */
 
 #ifndef _HASHTABLE_H
 #define _HASHTABLE_H
+#if defined(__cplusplus)
+extern "C"
+  {
+#endif
 
 typedef struct _Hash_table* Hash_table;
 
@@ -30,4 +40,7 @@ void*      hash_find(Hash_table,void* key,unsigned keysize);
 int        hash_add (Hash_table,void* key,unsigned keysize,
 		     void* value,unsigned valuesize);
 
+#if defined(__cplusplus)
+  }
 #endif
+#endif /* _HASHTABLE_H_ */
