@@ -1,59 +1,65 @@
 /* Eliot                                                                     */
 /* Copyright (C) 1999  Antoine Fraboulet                                     */
-/* Antoine.Fraboulet@free.fr                                                 */
 /*                                                                           */
-/* This program is free software; you can redistribute it and/or modify      */
+/* This file is part of Eliot.                                               */
+/*                                                                           */
+/* Eliot is free software; you can redistribute it and/or modify             */
 /* it under the terms of the GNU General Public License as published by      */
 /* the Free Software Foundation; either version 2 of the License, or         */
 /* (at your option) any later version.                                       */
 /*                                                                           */
-/* This program is distributed in the hope that it will be useful,           */
+/* Eliot is distributed in the hope that it will be useful,                  */
 /* but WITHOUT ANY WARRANTY; without even the implied warranty of            */
 /* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             */
 /* GNU General Public License for more details.                              */
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-/* $Id: configdb.cc,v 1.1 2004/04/08 09:43:06 afrab Exp $ */
+/**
+ *  \file   configdb.cc
+ *  \brief  Access to Eliot persistant configuration data
+ *  \author Antoine Fraboulet
+ *  \date   2002
+ */
 
 #include <iostream>
 #include "ewx.h"
 #include "configdb.h"
 #include "wx/colordlg.h"
 #include "wx/fontdlg.h"
-#include "wx/settings.h" 
+#include "wx/settings.h"
 
 using namespace std;
 
 #define DIM 200
 #define PREFIX  "/"
 
-#define DICPATH  PREFIX"Fichiers/Dictionnaire_Chemin"
-#define DICNAME  PREFIX"Fichiers/Dictionnaire_Nom"
-#define TILEPATH PREFIX"Fichiers/Lettres_Chemin"
-#define TILENAME PREFIX"Fichiers/Lettres_Nom"
+#define DICPATH  wxT(PREFIX"Fichiers/Dictionnaire_Chemin")
+#define DICNAME  wxT(PREFIX"Fichiers/Dictionnaire_Nom")
+#define TILEPATH wxT(PREFIX"Fichiers/Lettres_Chemin")
+#define TILENAME wxT(PREFIX"Fichiers/Lettres_Nom")
 
 ///////////////////////////
 //
 // Print
 //
 ///////////////////////////
-#define ORIENT  PREFIX"Print/Page_Orientation"
-#define MARGINX PREFIX"Print/Page_MargeGauche"
-#define MARGINY PREFIX"Print/Page_MargeHaute"
+#define ORIENT  wxT(PREFIX"Print/Page_Orientation")
+#define MARGINX wxT(PREFIX"Print/Page_MargeGauche")
+#define MARGINY wxT(PREFIX"Print/Page_MargeHaute")
 
-#define HNAME   PREFIX"Print/Header/Nom/"
-#define HDIM    PREFIX"Print/Header/Dimensions/"
-#define HJUST   PREFIX"Print/Header/Justification/"
-#define HSPACE  PREFIX"Print/Header/Espacement/"
+#define HNAME   wxT(PREFIX"Print/Header/Nom/")
+#define HDIM    wxT(PREFIX"Print/Header/Dimensions/")
+#define HJUST   wxT(PREFIX"Print/Header/Justification/")
+#define HSPACE  wxT(PREFIX"Print/Header/Espacement/")
 
-#define TDIM    PREFIX"Print/Text/Dimensions/"
-#define TJUST   PREFIX"Print/Text/Justification/"
-#define TSPACE  PREFIX"Print/Text/Espacement/"
+#define TDIM    wxT(PREFIX"Print/Text/Dimensions/")
+#define TJUST   wxT(PREFIX"Print/Text/Justification/")
+#define TSPACE  wxT(PREFIX"Print/Text/Espacement/")
 
-#define MISC    PREFIX"Divers/"
+#define MISC    wxT(PREFIX"Divers/")
 
 ConfigDB::ConfigDB()
 {
@@ -91,13 +97,13 @@ long ConfigDB::Read(const wxString& key, long def)
   return res;
 }
 
-#define FPOINTSIZE ".PointSize"
-#define FFAMILY    ".Family"
-#define FSTYLE     ".Style"
-#define FWEIGHT    ".Weight"
-#define FUNDERLINE ".Underline"
-#define FFACENAME  ".FaceName"
-#define FENCODING  ".Encoding"
+#define FPOINTSIZE wxT(".PointSize")
+#define FFAMILY    wxT(".Family")
+#define FSTYLE     wxT(".Style")
+#define FWEIGHT    wxT(".Weight")
+#define FUNDERLINE wxT(".Underline")
+#define FFACENAME  wxT(".FaceName")
+#define FENCODING  wxT(".Encoding")
 
 wxFont ConfigDB::Read(const wxString& key, wxFont def)
 {
@@ -117,35 +123,35 @@ void ConfigDB::Write(const wxString& key, wxFont font)
   pConfig->Write(key + FFAMILY   ,(long)font.GetFamily());
   pConfig->Write(key + FSTYLE    ,(long)font.GetStyle());
   pConfig->Write(key + FWEIGHT   ,(long)font.GetWeight());
-  pConfig->Write(key + FUNDERLINE,(long)font.GetUnderlined()); 
+  pConfig->Write(key + FUNDERLINE,(long)font.GetUnderlined());
   pConfig->Write(key + FFACENAME ,font.GetFaceName());
   //pConfig->Write(key + FENCODING ,font.GetDefaultEncoding());
 }
 
-#define CR ".R"
-#define CG ".G"
-#define CB ".B"
+#define CR wxT(".R")
+#define CG wxT(".G")
+#define CB wxT(".B")
 
 wxColour ConfigDB::Read(const wxString& key, wxColour def)
 {
-  return wxColour(Read(key + CR,(long)def.Red()),
-		  Read(key + CG,(long)def.Green()),
-		  Read(key + CB,(long)def.Blue()));
+    return wxColour(Read(key + CR,(long)def.Red()),
+                    Read(key + CG,(long)def.Green()),
+                    Read(key + CB,(long)def.Blue()));
 }
 
 
 void ConfigDB::Write(const wxString& key, wxColour colour)
 {
-  pConfig->Write(key + CR,(long)colour.Red());
-  pConfig->Write(key + CG, (long)colour.Green());
-  pConfig->Write(key + CB, (long)colour.Blue());
+    pConfig->Write(key + CR,(long)colour.Red());
+    pConfig->Write(key + CG, (long)colour.Green());
+    pConfig->Write(key + CB, (long)colour.Blue());
 }
 
 wxString ConfigDB::ReadStr(const wxString& key, wxString def)
 {
   wxString res;
 
-  /*  
+  /*
   wxString msg;
   msg << "want to read -" << key << "-";
   wxMessageBox(msg, "Eliot configDB", wxICON_INFORMATION | wxOK);
@@ -188,22 +194,22 @@ void ConfigDB::Write(const wxString& key, wxString str)
 
 wxString ConfigDB::getDicPath()
 {
-  return ReadStr(DICPATH,wxString("//"));
+  return ReadStr(DICPATH,wxT("//"));
 }
 
 wxString ConfigDB::getDicName()
 {
-  return ReadStr(DICNAME,wxString("Aucun Dictionnaire"));
+  return ReadStr(DICNAME,wxT("Aucun Dictionnaire"));
 }
 
 wxString ConfigDB::getTilePath()
 {
-  return ReadStr(TILEPATH,wxString("//"));
+  return ReadStr(TILEPATH,wxT("//"));
 }
 
 wxString ConfigDB::getTileName()
 {
-  return ReadStr(TILENAME,wxString(""));
+  return ReadStr(TILENAME,wxT(""));
 }
 
 void ConfigDB::setDicPath(wxString dpath, wxString dname)
@@ -237,7 +243,7 @@ void ConfigDB::setDxBegin(long d)
 long ConfigDB::getDxText(int i)
 {
   long int res;
-  switch (i) 
+  switch (i)
     {
     case 0: res = Read(TDIM"texte/1",10L); break;
     case 1: res = Read(TDIM"texte/2",30L); break;
@@ -252,7 +258,7 @@ long ConfigDB::getDxText(int i)
 void ConfigDB::setDxText(int i, long v)
 {
   wxString key;
-  key << TDIM << "texte/" << (i+1);
+  key << TDIM << wxT("texte/") << (i+1);
   if (i<5)
     Write(key,v);
 }
@@ -310,14 +316,14 @@ void ConfigDB::setDyH2(long d)
 wxString ConfigDB::getNameH(int i)
 {
   wxString res;
-  switch (i) 
+  switch (i)
     {
-    case 0: res = ReadStr(wxString(HNAME)+wxString("1"),wxString("Num")); break;
-    case 1: res = ReadStr(wxString(HNAME)+wxString("2"),wxString("Tirage")); break;
-    case 2: res = ReadStr(wxString(HNAME)+wxString("3"),wxString("Solution")); break;
-    case 3: res = ReadStr(wxString(HNAME)+wxString("4"),wxString("Pos")); break;
-    case 4: res = ReadStr(wxString(HNAME)+wxString("5"),wxString("Pts")); break;
-    default: res = ""; break;
+    case 0: res = ReadStr(wxString(HNAME) + wxT("1"), wxT("Num")); break;
+    case 1: res = ReadStr(wxString(HNAME) + wxT("2"), wxT("Tirage")); break;
+    case 2: res = ReadStr(wxString(HNAME) + wxT("3"), wxT("Solution")); break;
+    case 3: res = ReadStr(wxString(HNAME) + wxT("4"), wxT("Pos")); break;
+    case 4: res = ReadStr(wxString(HNAME) + wxT("5"), wxT("Pts")); break;
+    default: res = wxT(""); break;
   }
   return res;
 }
@@ -338,11 +344,11 @@ void ConfigDB::setNameH(int i, wxString str)
 enum Justif ConfigDB::StrToJust(const wxString& str)
 {
   enum Justif res;
-  if (str.CmpNoCase("gauche") == 0)
+  if (str.CmpNoCase(wxT("gauche")) == 0)
     res = LEFT;
-  else if (str.CmpNoCase("centre") == 0)
+  else if (str.CmpNoCase(wxT("centre")) == 0)
     res = CENTER;
-  else if (str.CmpNoCase("droite") == 0)
+  else if (str.CmpNoCase(wxT("droite")) == 0)
     res = RIGHT;
   else
     res = LEFT;
@@ -353,16 +359,16 @@ wxString ConfigDB::JustToStr(enum Justif j)
 {
   wxString res;
   switch (j) {
-  case LEFT:   res = "gauche"; break;
-  case CENTER: res = "centre"; break;
-  case RIGHT:  res = "droite"; break;
+  case LEFT:   res = wxT("gauche"); break;
+  case CENTER: res = wxT("centre"); break;
+  case RIGHT:  res = wxT("droite"); break;
   }
   return res;
 }
 
 enum Justif ConfigDB::getJustif(const wxString& key)
 {
-  return StrToJust(ReadStr(key,wxString("gauche")));
+  return StrToJust(ReadStr(key,wxT("gauche")));
 }
 
 void ConfigDB::setJustif(const wxString& key, enum Justif j)
@@ -458,13 +464,18 @@ wxFont ConfigDB::ChooseFont(wxFrame* frame,wxFont initfont)
 void ConfigDB::setFontDefault()
 {
   wxFont fsys;
+
+#ifdef WXWIN24
   fsys = wxSystemSettings::GetSystemFont(wxSYS_DEFAULT_GUI_FONT);
+#else
+  fsys = wxSystemSettingsNative::GetFont(wxSYS_DEFAULT_GUI_FONT);
+#endif
 
   setFont(BOARDFONT ,fsys);
   setFont(LISTFONT  ,fsys);
   setFont(PRINTHFONT,FHEADERDEF);
   setFont(PRINTTFONT,FTEXTDEF);
-}  
+}
 
 void ConfigDB::setFont(wxString key, wxFont font)
 {
@@ -504,6 +515,10 @@ wxColour ConfigDB::ChooseColour(wxFrame* frame,wxColour initcolour)
 #define BACKDEF    wxColour(255,255,255)
 #define LETTDEF    wxColour(  0,  0,  0)
 #define TSTLETTDEF wxColour(  0,  0,  0)
+#define TILEDEF    wxColour(0xff,0xeb,0xcd)
+//#define TSTTILEDEF wxColour(0xff,0xe4,0xb5)
+//#define TSTTILEDEF wxColour(0x46,0x82,0xb4)
+#define TSTTILEDEF wxColour(0xbd,0xb7,0x7b)
 
 void ConfigDB::setColourDefault()
 {
@@ -514,6 +529,8 @@ void ConfigDB::setColourDefault()
   setColour(wxString(BCOLOURLX3),LX3DEF);
   setColour(wxString(BCOLOURBACKGROUND),BACKDEF);
   setColour(wxString(BCOLOURLETTERS),LETTDEF);
+  setColour(wxString(BTILEBACKGROUND),TILEDEF);
+  setColour(wxString(BTSTTILEBACKGROUND),TSTTILEDEF);
 }
 
 void
@@ -530,7 +547,7 @@ ConfigDB::getColour(wxString key)
 
 ////////////////////////////////////////////////////////
 //
-// PRINTING 
+// PRINTING
 //
 ////////////////////////////////////////////////////////
 
@@ -558,11 +575,11 @@ long ConfigDB::getOrientation()
 {
   long res;
   wxString str;
-  
-  str = ReadStr(ORIENT,"paysage");
-  if (str.CmpNoCase("portrait") == 0)
+
+  str = ReadStr(ORIENT,wxT("paysage"));
+  if (str.CmpNoCase(wxT("portrait")) == 0)
     res = wxPORTRAIT;
-  else if (str.CmpNoCase("paysage") == 0)
+  else if (str.CmpNoCase(wxT("paysage")) == 0)
     res = wxLANDSCAPE;
   else
     res = wxPORTRAIT;
@@ -571,11 +588,11 @@ long ConfigDB::getOrientation()
 
 void ConfigDB::setOrientation(long o)
 {
-  switch (o) 
+  switch (o)
     {
-    case wxLANDSCAPE: Write(ORIENT,wxString("paysage")); break;
+    case wxLANDSCAPE: Write(ORIENT,wxT("paysage")); break;
     case wxPORTRAIT: // fall through
-    default: Write(ORIENT,wxString("portrait")); break;
+    default: Write(ORIENT,wxT("portrait")); break;
     }
 }
 
@@ -610,7 +627,7 @@ float ConfigDB::getPrintLineScale()
   return 0.2;
 }
 
-void ConfigDB::setPrintLineScale(float s)
+void ConfigDB::setPrintLineScale(float)
 {
 }
 
@@ -620,11 +637,11 @@ void ConfigDB::setPrintLineScale(float s)
 //
 ////////////////////////////////////////////////////////
 
-#define PX "/x"
-#define PY "/y"
-#define SW "/w"
-#define SH "/h"
-#define SHOW "/show"
+#define PX wxT("/x")
+#define PY wxT("/y")
+#define SW wxT("/w")
+#define SH wxT("/h")
+#define SHOW wxT("/show")
 
 #define CONFIG_DEFAULT_X 150L
 #define CONFIG_DEFAULT_Y 150L
@@ -636,10 +653,14 @@ wxPoint ConfigDB::getFramePos(wxString frame)
   wxPoint pos;
   wxString keyX(frame + PX);
   wxString keyY(frame + PY);
+
   pos.x = Read(keyX,CONFIG_DEFAULT_X);
+  pos.x = pos.x < 0 ? 0 : pos.x;
+
   pos.y = Read(keyY,CONFIG_DEFAULT_Y);
+  pos.y = pos.y < 0 ? 0 : pos.y;
 #ifdef FRAME_TRACE
-  cerr << "configdb::getFramePos  " << frame 
+  cerr << "configdb::getFramePos  " << frame
        << " \tx:" << pos.x << " y:" << pos.y << endl;
 #endif
   return pos;
@@ -648,13 +669,13 @@ wxPoint ConfigDB::getFramePos(wxString frame)
 void ConfigDB::setFramePos(wxString frame, wxPoint pos)
 {
 #ifdef FRAME_TRACE
-  cerr << "configdb::setFramePos  " << frame 
+  cerr << "configdb::setFramePos  " << frame
        << " \tx:" << pos.x << " y:" << pos.y << endl;
 #endif
   wxString keyX(frame + PX);
   wxString keyY(frame + PY);
-  Write(keyX,(long)pos.x);
-  Write(keyY,(long)pos.y);
+  Write(keyX,(long) (pos.x < 0 ? 0 : pos.x));
+  Write(keyY,(long) (pos.y < 0 ? 0 : pos.y));
 }
 
 wxSize ConfigDB::getFrameSize(wxString frame)
@@ -662,25 +683,29 @@ wxSize ConfigDB::getFrameSize(wxString frame)
   wxSize size;
   wxString keyX(frame + SW);
   wxString keyY(frame + SH);
+
   size.x = Read(keyX,CONFIG_DEFAULT_W);
+  size.x = size.x < 0 ? 0 : size.x;
+
   size.y = Read(keyY,CONFIG_DEFAULT_H);
+  size.y = size.y < 0 ? 0 : size.y;
 #ifdef FRAME_TRACE
-  cerr << "configdb::getFrameSize " << frame 
+  cerr << "configdb::getFrameSize " << frame
        << " \tw:" << size.x << " h:" << size.y << endl;
-#endif  
+#endif
   return size;
 }
 
 void ConfigDB::setFrameSize(wxString frame, wxSize size)
 {
 #ifdef FRAME_TRACE
-  cerr << "configdb::setFrameSize " << frame 
+  cerr << "configdb::setFrameSize " << frame
        << " \tw:" << size.x << " h:" << size.y << endl;
 #endif
   wxString keyX(frame + SW);
   wxString keyY(frame + SH);
-  Write(keyX,(long)size.x);
-  Write(keyY,(long)size.y);
+  Write(keyX,(long) (size.x < 0 ? 0 : size.x));
+  Write(keyY,(long) (size.y < 0 ? 0 : size.y));
 }
 
 int ConfigDB::getFrameShow(wxString frame)
@@ -697,14 +722,14 @@ void ConfigDB::setFrameShow(wxString frame, int s)
 
 void ConfigDB::setFrameDefault()
 {
-  setFrameSize(FRAMEBOARD ,wxSize(450,450));
-  setFrameSize(FRAMEVERIF ,wxSize(150,50));
-  setFrameSize(FRAMESEARCH,wxSize(350,300));
-  setFrameSize(FRAMEPLUS1 ,wxSize(CONFIG_DEFAULT_W,CONFIG_DEFAULT_H));
-  setFrameSize(FRAMERACC  ,wxSize(CONFIG_DEFAULT_W,CONFIG_DEFAULT_H));
-  setFrameSize(FRAMEBENJ  ,wxSize(CONFIG_DEFAULT_W,CONFIG_DEFAULT_H));
-  setFrameSize(FRAMEBAG   ,wxSize(150,40));
-  setFrameSize(APPNAME    ,wxSize(410,200));
+  setFrameSize(FRAMEBOARD  ,wxSize(450,450));
+  setFrameSize(FRAMEVERIF  ,wxSize(150,50));
+  setFrameSize(FRAMESEARCH ,wxSize(350,300));
+  setFrameSize(FRAMEPLUS1  ,wxSize(CONFIG_DEFAULT_W,CONFIG_DEFAULT_H));
+  setFrameSize(FRAMERACC   ,wxSize(CONFIG_DEFAULT_W,CONFIG_DEFAULT_H));
+  setFrameSize(FRAMEBENJ   ,wxSize(CONFIG_DEFAULT_W,CONFIG_DEFAULT_H));
+  setFrameSize(FRAMEBAG    ,wxSize(150,40));
+  setFrameSize(wxT(APPNAME),wxSize(410,200));
 
   setFramePos(FRAMEBOARD  ,wxPoint(58,76));
   setFramePos(FRAMEVERIF  ,wxPoint(CONFIG_DEFAULT_X,CONFIG_DEFAULT_Y));
@@ -713,7 +738,7 @@ void ConfigDB::setFrameDefault()
   setFramePos(FRAMERACC   ,wxPoint(CONFIG_DEFAULT_X,CONFIG_DEFAULT_Y));
   setFramePos(FRAMEBENJ   ,wxPoint(CONFIG_DEFAULT_X,CONFIG_DEFAULT_Y));
   setFramePos(FRAMEBAG    ,wxPoint(CONFIG_DEFAULT_X,CONFIG_DEFAULT_Y));
-  setFramePos(APPNAME     ,wxPoint(500,9));
+  setFramePos(wxT(APPNAME),wxPoint(500,9));
 
   setFrameShow(FRAMEBOARD ,1L);
   setFrameShow(FRAMEVERIF ,0L);
@@ -736,38 +761,52 @@ void ConfigDB::setFrameDefault()
 void ConfigDB::setJokerPlus1(bool val)
 {
   wxString key;
-  key = wxString(MISC) + wxString("JokersDans7plus1");
+  key = wxString(MISC) + wxT("JokersDans7plus1");
   Write(key,val);
 }
 
 bool ConfigDB::getJokerPlus1()
 {
   wxString key;
-  key = wxString(MISC) + wxString("JokersDans7plus1");
+  key = wxString(MISC) + wxT("JokersDans7plus1");
   return Read(key,(bool)FALSE);
 }
 
 void ConfigDB::setRackChecking(bool val)
 {
   wxString key;
-  key = wxString(MISC) + wxString("VerificationTirages");
+  key = wxString(MISC) + wxT("VerificationTirages");
   Write(key,val);
 }
 
 bool ConfigDB::getRackChecking()
 {
   wxString key;
-  key = wxString(MISC) + wxString("VerificationTirages");
+  key = wxString(MISC) + wxT("VerificationTirages");
   return Read(key,(bool)FALSE);
 }
 
+void ConfigDB::setDrawTile(bool val)
+{
+  wxString key;
+  key = wxString(BDRAWBACKGROUND);
+  Write(key,val);
+}
+
+bool ConfigDB::getDrawTile()
+{
+  wxString key;
+  key = wxString(BDRAWBACKGROUND);
+  return Read(key,(bool)TRUE);
+}
+
 ////////////////////////////////////////////////////////
 //
-// 
+//
 //
 ////////////////////////////////////////////////////////
 
-#define INIT "/Initialized"
+#define INIT wxT("/Initialized")
 
 void
 ConfigDB::setFirstDefault()
@@ -781,4 +820,3 @@ ConfigDB::setFirstDefault()
 
   Write(wxString(INIT),1L);
 }
-
