@@ -14,18 +14,31 @@
 /*                                                                           */
 /* You should have received a copy of the GNU General Public License         */
 /* along with this program; if not, write to the Free Software               */
-/* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
 
-/* $Id: main.cc,v 1.1 2004/04/08 09:43:06 afrab Exp $ */
+/**
+ *  \file   main.cc
+ *  \brief  Eliot main entry point
+ *  \author Antoine Fraboulet
+ *  \date   2005
+ */
+
+#ifdef WIN32 // mingw32 hack
+#   undef Yield
+#   undef CreateDialog
+#endif
 
 #include <stdlib.h>
 #include <time.h>
+#include <wx/wxprec.h>
+#include <wx/wx.h>
+#include <wx/app.h>
+#include <wx/intl.h>
+
 #include "ewx.h"
 #include "configdb.h"
 #include "mainframe.h"
-
-#include "wx/app.h"
-#include "wx/intl.h"
+#include "game_factory.h"
 
 #include "eliot.xpm"
 
@@ -46,32 +59,51 @@ IMPLEMENT_APP(EliotApp)
 bool
 EliotApp::OnInit()
 {
-     srand(time(NULL));
-     SetVendorName("Afrab");
-     SetAppName("eliot");
-     SetClassName("eliot");
+    srand(time(NULL));
+    SetVendorName(wxT("Afrab"));
+    SetAppName(wxString(wxT("eliot")) + wxT("-") + wxT(VERSION));
+    SetClassName(wxT("eliot"));
 
-     wxConfigBase* config = wxConfigBase::Get();
-     config = NULL;
+    wxConfigBase* config = wxConfigBase::Get();
+    config = NULL;
 #ifdef ENABLE_LOCALE
-     locale.Init(wxLocale::GetSystemLanguage(),
-		 wxLOCALE_LOAD_DEFAULT | wxLOCALE_CONV_ENCODING);
+    locale.Init(wxLocale::GetSystemLanguage(),
+                wxLOCALE_LOAD_DEFAULT | wxLOCALE_CONV_ENCODING);
+
+    wxLocale::AddCatalogLookupPathPrefix(wxT("."));
+    wxLocale::AddCatalogLookupPathPrefix(wxT(".."));
+    wxLocale::AddCatalogLookupPathPrefix(wxT("./po"));
+    wxLocale::AddCatalogLookupPathPrefix(wxT("../po"));
+    locale.AddCatalog(wxT("wxeliot"));
+#ifdef __LINUX__
+    {
+        wxLogNull noLog;
+        locale.AddCatalog(_T("fileutils"));
+    }
 #endif
-     ConfigDB configdb;
-     configdb.setFirstDefault();
-     MainFrame *mainframe = new MainFrame(configdb.getFramePos(APPNAME),
-					  configdb.getFrameSize(APPNAME));
-     mainframe->SetIcon( wxICON(eliot) );
-     mainframe->Show(TRUE);
-     SetTopWindow(mainframe);
-     return TRUE;
+#endif
+    ConfigDB configdb;
+    configdb.setFirstDefault();
+    MainFrame *mainframe = new MainFrame(configdb.getFramePos(wxT(APPNAME)),
+                                         configdb.getFrameSize(wxT(APPNAME)));
+    mainframe->SetIcon(wxICON(eliot));
+    mainframe->Show(TRUE);
+    SetTopWindow(mainframe);
+    return TRUE;
 }
 
 int
 EliotApp::OnExit()
 {
-  delete wxConfigBase::Set((wxConfigBase *) NULL);
-  return 0;
+    GameFactory::Destroy();
+    delete wxConfigBase::Set((wxConfigBase *) NULL);
+    return 0;
 }
 
 
+/// Local Variables:
+/// mode: c++
+/// mode: hs-minor
+/// c-basic-offset: 4
+/// indent-tabs-mode: nil
+/// End:
